A PEP 517 backend for the [Coherent Software Development System](https://github.com/coherent-oss/system/blob/main/README.md).

Put your source in a repo and then build it with:

```
python -m coherent.build
```
